@@ -1,4 +1,4 @@
-""" APIs of data """
+from ._accumulate_data import AccumulateData
 from .mean_var_data import MeanVarData
 from .mean_var_data_rep import MeanVarDataRep
 from .ld_transform_data import LDTransformData
